summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteonlinestatusmanager.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteonlinestatusmanager.h')
-rw-r--r--kopete/libkopete/kopeteonlinestatusmanager.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/libkopete/kopeteonlinestatusmanager.h b/kopete/libkopete/kopeteonlinestatusmanager.h
index 8edd8861..e286dafc 100644
--- a/kopete/libkopete/kopeteonlinestatusmanager.h
+++ b/kopete/libkopete/kopeteonlinestatusmanager.h
@@ -54,9 +54,9 @@ public:
*
* Idle is the status used for auto-away
*
- * Status number are organised so that make a tree.
+ * tqStatus number are organised so that make a tree.
*/
//please be carrefull when modifying values of status. read comment in onlineStatus()
enum Categories
{
Idle=1<<8, ExtendedAway=1<<9 , Invisible=1<<10,
@@ -122,7 +122,7 @@ public:
*
* If no status has been registered in this category, return the one in the category which is the most similair
*/
- OnlineStatus onlineStatus(Protocol *protocol, Categories category) const;
+ OnlineStatus onlinetqStatus(Protocol *protocol, Categories category) const;
private:
friend class OnlineStatus;
@@ -54,9 +54,9 @@ public:
*/
- //please be carrefull when modifying values of status. read comment in onlineStatus()
+ //please be carrefull when modifying values of status. read comment in onlinetqStatus()
enum Categories
{